==> topia-persistence-2.7-sources.jar: org/nuiton/topia/persistence/TopiaPersistenceHelper.java <==
package org.nuiton.topia.persistence;
/*
 * #%L
 * ToPIA :: Persistence
 * $Id: TopiaPersistenceHelper.java 2641 2012-08-22 16:04:01Z tchemit $
 * $HeadURL: http://svn.nuiton.org/svn/topia/tags/topia-2.7/topia-persistence/src/main/java/org/nuiton/topia/persistence/TopiaPersistenceHelper.java $
 * %%
 * Copyright (C) 2004 - 2012 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>.
 * #L%
 */

import org.nuiton.topia.TopiaContext;

/**
 * Object which helps to wrap some static generated code
 * (dao helper, entityEnum).
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 2.6.12
 */
public interface TopiaPersistenceHelper<T extends TopiaEntityEnum> {

    <E extends TopiaEntity> T getEntityEnum(Class<E> type);

    <E extends TopiaEntity> TopiaDAO<E> getDAO(TopiaContext tx, Class<E> type);

    <E extends TopiaEntity> TopiaDAO<E> getDAO(TopiaContext tx, T type);

}

==> topia-persistence-2.7.1-sources.jar: org/nuiton/topia/persistence/TopiaPersistenceHelper.java <==
package org.nuiton.topia.persistence;
/*
 * #%L
 * ToPIA :: Persistence
 * $Id: TopiaPersistenceHelper.java 2641 2012-08-22 16:04:01Z tchemit $
 * $HeadURL: http://svn.nuiton.org/svn/topia/tags/topia-2.7.1/topia-persistence/src/main/java/org/nuiton/topia/persistence/TopiaPersistenceHelper.java $
 * %%
 * Copyright (C) 2004 - 2012 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>.
 * #L%
 */

import org.nuiton.topia.TopiaContext;

/**
 * Object which helps to wrap some static generated code
 * (dao helper, entityEnum).
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 2.6.12
 */
public interface TopiaPersistenceHelper<T extends TopiaEntityEnum> {

    <E extends TopiaEntity> T getEntityEnum(Class<E> type);

    <E extends TopiaEntity> TopiaDAO<E> getDAO(TopiaContext tx, Class<E> type);

    <E extends TopiaEntity> TopiaDAO<E> getDAO(TopiaContext tx, T type);

}
